aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--ext/pui-event.lv2/manifest.ttl (renamed from ext/ui-event.lv2/manifest.ttl)4
-rw-r--r--ext/pui-event.lv2/pui-event.h (renamed from ext/ui-event.lv2/ui-event.h)10
-rw-r--r--ext/pui-event.lv2/pui-event.ttl (renamed from ext/ui-event.lv2/ui-event.ttl)32
-rw-r--r--ext/pui-gtk.lv2/manifest.ttl (renamed from ext/ui-gtk.lv2/manifest.ttl)4
-rw-r--r--ext/pui-gtk.lv2/pui-gtk.h (renamed from ext/ui-gtk.lv2/ui-gtk.h)10
-rw-r--r--ext/pui-gtk.lv2/pui-gtk.ttl (renamed from ext/ui-gtk.lv2/ui-gtk.ttl)16
-rw-r--r--ext/pui.lv2/manifest.ttl (renamed from ext/ui.lv2/manifest.ttl)4
-rw-r--r--ext/pui.lv2/pui.h (renamed from ext/ui.lv2/ui.h)124
-rw-r--r--ext/pui.lv2/pui.ttl (renamed from ext/ui.lv2/ui.ttl)44
9 files changed, 122 insertions, 126 deletions
diff --git a/ext/ui-event.lv2/manifest.ttl b/ext/pui-event.lv2/manifest.ttl
index d37bb13..e0b87b5 100644
--- a/ext/ui-event.lv2/manifest.ttl
+++ b/ext/pui-event.lv2/manifest.ttl
@@ -1,8 +1,8 @@
@prefix lv2: <http://lv2plug.in/ns/lv2core#>.
@prefix rdfs: <http://www.w3.org/2000/01/rdf-schema#>.
-<http://lv2plug.in/ns/ext/ui-event>
+<http://lv2plug.in/ns/ext/pui-event>
a lv2:Specification;
lv2:minorVersion 0;
lv2:microVersion 1;
- rdfs:seeAlso <ui-event.ttl>.
+ rdfs:seeAlso <pui-event.ttl>.
diff --git a/ext/ui-event.lv2/ui-event.h b/ext/pui-event.lv2/pui-event.h
index 16739f7..223b5f5 100644
--- a/ext/ui-event.lv2/ui-event.h
+++ b/ext/pui-event.lv2/pui-event.h
@@ -1,8 +1,8 @@
/************************************************************************
*
- * Event port protocol for the in-process LV2 UI extension
+ * Event port protocol for the LV2 plugin UI extension
*
- * Copyright (C) 2010 Lars Luthman <mail@larsluthman.net>
+ * Copyright (C) 2010-2011 Lars Luthman <mail@larsluthman.net>
*
* This header is free software; you can redistribute it and/or modify it
* under the terms of the GNU Lesser General Public License as published
@@ -26,12 +26,12 @@
for this extension.
*/
-#ifndef LV2_UI_EVENT_H
-#define LV2_UI_EVENT_H
+#ifndef LV2_PUI_EVENT_H
+#define LV2_PUI_EVENT_H
/** The URI prefix for this extension. */
-#define LV2_UI_EVENT_URI "http://lv2plug.in/ns/ext/ui-event"
+#define LV2_PUI_EVENT_URI "http://lv2plug.in/ns/ext/pui-event"
#endif
diff --git a/ext/ui-event.lv2/ui-event.ttl b/ext/pui-event.lv2/pui-event.ttl
index c47fe4d..6133b38 100644
--- a/ext/ui-event.lv2/ui-event.ttl
+++ b/ext/pui-event.lv2/pui-event.ttl
@@ -1,15 +1,13 @@
-# In-process UI extension
+# Plugin UI extension
#
# Copyright (C) 2010-2011 Lars Luthman <mail@larsluthman.net>
#
# based on lv2.ttl, which is
# Copyright (C) 2006-2008 Steve Harris, David Robillard
#
-# This extension should be considered a replacement for the earlier
-# in-process UI extension with the URI <http://lv2plug.in/ns/extensions/ui>.
-# Hosts and plugins that used that extension should use this one instead.
-# The earlier in-process UI extension is not compatible with LV2 revision 3
-# and later and may break in subtle ways.
+# This extension specifies a method for plugin UIs, as defined in the
+# extension <http://lv2plug.in/ns/ext/pui>, to send events to a plugin's
+# event ports and to monitor incoming and outgoing events.
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this software and associated documentation files (the "Software"),
@@ -29,16 +27,16 @@
# ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
# OTHER DEALINGS IN THE SOFTWARE.
-@prefix ui: <http://lv2plug.in/ns/ext/ui#>.
-@prefix ev: <http://lv2plug.in/ns/ext/event#>.
-@prefix uiev: <http://lv2plug.in/ns/ext/ui-event#>.
-@prefix lv2: <http://lv2plug.in/ns/lv2core#>.
-@prefix rdf: <http://www.w3.org/1999/02/22-rdf-syntax-ns#>.
-@prefix rdfs: <http://www.w3.org/2000/01/rdf-schema#>.
-@prefix doap: <http://usefulinc.com/ns/doap#>.
-@prefix foaf: <http://xmlns.com/foaf/0.1/>.
+@prefix pui: <http://lv2plug.in/ns/ext/pui#>.
+@prefix ev: <http://lv2plug.in/ns/ext/event#>.
+@prefix puiev: <http://lv2plug.in/ns/ext/pui-event#>.
+@prefix lv2: <http://lv2plug.in/ns/lv2core#>.
+@prefix rdf: <http://www.w3.org/1999/02/22-rdf-syntax-ns#>.
+@prefix rdfs: <http://www.w3.org/2000/01/rdf-schema#>.
+@prefix doap: <http://usefulinc.com/ns/doap#>.
+@prefix foaf: <http://xmlns.com/foaf/0.1/>.
-<http://lv2plug.in/ns/ext/ui-event> a lv2:Specification ;
+<http://lv2plug.in/ns/ext/pui-event> a lv2:Specification ;
doap:license <http://usefulinc.com/doap/licenses/mit>;
doap:name "LV2 UI Event port protocol" ;
doap:release [
@@ -51,11 +49,11 @@
foaf:mbox <mailto:mail@larsluthman.net>;
];
lv2:documentation """
-This extension defines an ui:PortProtocol for passing events (MIDI, OSC,
+This extension defines an pui:PortProtocol for passing events (MIDI, OSC,
etc.) between LV2 plugins and UIs.
""".
-uiev:events a ui:PortProtocol;
+puiev:events a pui:PortProtocol;
rdfs:label "Event buffer";
lv2:documentation """
<ol>
diff --git a/ext/ui-gtk.lv2/manifest.ttl b/ext/pui-gtk.lv2/manifest.ttl
index dfac316..0de856b 100644
--- a/ext/ui-gtk.lv2/manifest.ttl
+++ b/ext/pui-gtk.lv2/manifest.ttl
@@ -1,8 +1,8 @@
@prefix lv2: <http://lv2plug.in/ns/lv2core#>.
@prefix rdfs: <http://www.w3.org/2000/01/rdf-schema#>.
-<http://lv2plug.in/ns/ext/ui-gtk>
+<http://lv2plug.in/ns/ext/pui-gtk>
a lv2:Specification;
lv2:minorVersion 0;
lv2:microVersion 1;
- rdfs:seeAlso <ui-gtk.ttl>.
+ rdfs:seeAlso <pui-gtk.ttl>.
diff --git a/ext/ui-gtk.lv2/ui-gtk.h b/ext/pui-gtk.lv2/pui-gtk.h
index 05c9316..12c58e1 100644
--- a/ext/ui-gtk.lv2/ui-gtk.h
+++ b/ext/pui-gtk.lv2/pui-gtk.h
@@ -1,8 +1,8 @@
/************************************************************************
*
- * Gtk+ 2.0 UI type for the in-process LV2 UI extension
+ * Gtk+ 2.0 UI type for the LV2 plugin UI extension
*
- * Copyright (C) 2010 Lars Luthman <mail@larsluthman.net>
+ * Copyright (C) 2010-2011 Lars Luthman <mail@larsluthman.net>
*
* This header is free software; you can redistribute it and/or modify it
* under the terms of the GNU Lesser General Public License as published
@@ -26,12 +26,12 @@
for this extension.
*/
-#ifndef LV2_UI_GTK_H
-#define LV2_UI_GTK_H
+#ifndef LV2_PUI_GTK_H
+#define LV2_PUI_GTK_H
/** The URI prefix for this extension. */
-#define LV2_UI_GTK_URI "http://lv2plug.in/ns/ext/ui-gtk"
+#define LV2_PUI_GTK_URI "http://lv2plug.in/ns/ext/pui-gtk"
#endif
diff --git a/ext/ui-gtk.lv2/ui-gtk.ttl b/ext/pui-gtk.lv2/pui-gtk.ttl
index ce77cba..5bce34e 100644
--- a/ext/ui-gtk.lv2/ui-gtk.ttl
+++ b/ext/pui-gtk.lv2/pui-gtk.ttl
@@ -1,4 +1,4 @@
-# Gtk UI extension for the in-process UI extension
+# Gtk UI extension for the plugin UI extension
#
# Copyright (C) 2010-2011 Lars Luthman <mail@larsluthman.net>
#
@@ -23,15 +23,15 @@
# ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
# OTHER DEALINGS IN THE SOFTWARE.
-@prefix ui-gtk: <http://lv2plug.in/ns/ext/ui-gtk#>.
-@prefix ui: <http://lv2plug.in/ns/ext/ui#>.
+@prefix pui-gtk: <http://lv2plug.in/ns/ext/pui-gtk#>.
+@prefix pui: <http://lv2plug.in/ns/ext/pui#>.
@prefix lv2: <http://lv2plug.in/ns/lv2core#>.
@prefix rdf: <http://www.w3.org/1999/02/22-rdf-syntax-ns#> .
@prefix rdfs: <http://www.w3.org/2000/01/rdf-schema#> .
@prefix doap: <http://usefulinc.com/ns/doap#> .
@prefix foaf: <http://xmlns.com/foaf/0.1/> .
-<http://lv2plug.in/ns/ext/ui-gtk> a lv2:Specification ;
+<http://lv2plug.in/ns/ext/pui-gtk> a lv2:Specification ;
doap:license <http://usefulinc.com/doap/licenses/mit>;
doap:name "LV2 Gtk+ UI" ;
doap:release [
@@ -48,8 +48,8 @@ This extension defines an UI type for the in-process UI extension that can be
used in a Gtk+ program.
""".
-ui-gtk:GtkUI a rdfs:Class;
- rdfs:subClassOf ui:UI;
+pui-gtk:GtkUI a rdfs:Class;
+ rdfs:subClassOf pui:UI;
rdfs:label "Gtk+ UI";
lv2:documentation """
<p>The class which represents a Gtk+ UI. For a successfully created instance of
@@ -59,11 +59,11 @@ the Gtk+ library has been initialised and that the Glib main loop is running
before an UI of this type is instantiated.</p>
<p>Unless otherwise specified by extensions, all function pointers in
-LV2_UI_Descriptor may only be called from the thread that runs the Glib main
+LV2_PUI_Descriptor may only be called from the thread that runs the Glib main
loop.</p>
""" .
-ui-gtk:noHostResize a lv2:Feature;
+pui-gtk:noHostResize a lv2:Feature;
rdfs:label "No host resize";
lv2:documentation """
<p>This Feature should only be used with UIs.</p>
diff --git a/ext/ui.lv2/manifest.ttl b/ext/pui.lv2/manifest.ttl
index 79f73e6..1229118 100644
--- a/ext/ui.lv2/manifest.ttl
+++ b/ext/pui.lv2/manifest.ttl
@@ -1,8 +1,8 @@
@prefix lv2: <http://lv2plug.in/ns/lv2core#>.
@prefix rdfs: <http://www.w3.org/2000/01/rdf-schema#>.
-<http://lv2plug.in/ns/ext/ui>
+<http://lv2plug.in/ns/ext/pui>
a lv2:Specification;
lv2:minorVersion 0;
lv2:microVersion 1;
- rdfs:seeAlso <ui.ttl>.
+ rdfs:seeAlso <pui.ttl>.
diff --git a/ext/ui.lv2/ui.ttl b/ext/pui.lv2/pui.ttl
index 3839f38..425047d 100644
--- a/ext/ui.lv2/ui.ttl
+++ b/ext/pui.lv2/pui.ttl
@@ -1,4 +1,4 @@
-# LV2 UI Extension
+# LV2 Plugin UI Extension
# Copyright (C) 2010-2011 Lars Luthman <mail@larsluthman.net>
#
# Based on lv2.ttl, which is
@@ -28,14 +28,14 @@
# ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
# OTHER DEALINGS IN THE SOFTWARE.
-@prefix ui: <http://lv2plug.in/ns/ext/ui#>.
+@prefix pui: <http://lv2plug.in/ns/ext/pui#>.
@prefix lv2: <http://lv2plug.in/ns/lv2core#>.
@prefix rdf: <http://www.w3.org/1999/02/22-rdf-syntax-ns#> .
@prefix rdfs: <http://www.w3.org/2000/01/rdf-schema#> .
@prefix doap: <http://usefulinc.com/ns/doap#> .
@prefix foaf: <http://xmlns.com/foaf/0.1/> .
-<http://lv2plug.in/ns/ext/ui> a lv2:Specification ;
+<http://lv2plug.in/ns/ext/pui> a lv2:Specification ;
doap:license <http://usefulinc.com/doap/licenses/mit>;
doap:name "LV2 UI" ;
doap:release [
@@ -52,11 +52,11 @@
plugins. The UIs are code that reside in shared object files in an LV2
bundle and are referenced in the RDF data using the triples
<pre>
- @prefix ui: &lt;http://lv2plug.in/ns/ext/ui#&gt; .
- @prefix ui-gtk: &lt;http://lv2plug.in/ns/ext/ui-gtk#&gt; .
- &lt;http://example.org/my-ui&gt; a ui-gtk:GtkUI ;
+ @prefix pui: &lt;http://lv2plug.in/ns/ext/pui#&gt; .
+ @prefix pui-gtk: &lt;http://lv2plug.in/ns/ext/pui-gtk#&gt; .
+ &lt;http://example.org/my-ui&gt; a pui-gtk:GtkUI ;
lv2:appliesTo &lt;http://example.org/my-plugin&gt; ;
- ui:binary &lt;my-ui.so&gt; .
+ pui:binary &lt;my-ui.so&gt; .
</pre>
where <code>http://example.org/my-plugin</code> is the URI of the plugin,
<code>http://example.org/my-ui</code> is the URI of the plugin UI and
@@ -66,7 +66,7 @@ it is probably a good idea to keep them separate so that hosts that don't want
UIs don't have to load the UI code.</p>
<p>A UI MUST specify its class in the RDF data and the class MUST be a proper
-subclass of ui:UI, in this case ui-gtk:GtkUI. The class defines what type the
+subclass of pui:UI, in this case pui-gtk:GtkUI. The class defines what type the
UI is, e.g. what graphics toolkit it uses. There are no UI classes defined in
this extension, those are specified separately (and anyone can define their
own).</p>
@@ -87,8 +87,7 @@ plugin implementation do not have to be the same. There are many valid reasons
for having the plugin and the UI in different processes, or even on different
machines. This means that you can <b>not</b> use singletons and global
variables and expect them to refer to the same objects in the UI and the actual
-plugin. The function callback interface defined in the header
-<a href="../../doc/html/ui_8lv2_2ui_8h.html">ui<!-- hackety hack -->.h</a> is
+plugin. The function callback interface defined in the header pui.h is
all you can expect to work.</p>
""".
@@ -96,7 +95,7 @@ all you can expect to work.</p>
## UI Class ##
##############
-ui:UI a rdfs:Class;
+pui:UI a rdfs:Class;
rdfs:subClassOf lv2:Feature;
rdfs:label "UI";
lv2:documentation """
@@ -105,15 +104,15 @@ ui:UI a rdfs:Class;
<p>To be used by a host a UI MUST have at least the following properties:
<pre>
- rdf:type (with object a proper subclass of ui:UI)
+ rdf:type (with object a proper subclass of pui:UI)
doap:name (one without language tag)
lv2:binary (with a shared object file as object)
lv2:appliesTo (with a LV2 plugin as object)
</pre>
The rdf:type of an UI is used by the host to decide whether it supports the
-UI and how to handle the LV2_UI_Widget object that is returned by the UIs
-get_widget() function. For example, a type of ui-gtk:GtkGUI might tell the host
-that LV2_UI_Widget is a pointer to an object of a type defined in the Gtk+
+UI and how to handle the LV2_PUI_Widget object that is returned by the UIs
+get_widget() function. For example, a type of pui-gtk:GtkGUI might tell the host
+that LV2_PUI_Widget is a pointer to an object of a type defined in the Gtk+
library. No UI types are defined in this extension, that is intentionally
left for other extensions.
</p>
@@ -130,8 +129,7 @@ doesn't support all of its required features, and an UI MUST fail to
instantiate if the host doesn't pass all required features to instantiate().
</p>
-<p>For details about the C API used to load UIs, see the file
-<a href="../../doc/html/ui_8lv2_2ui_8h.html">ui<!-- hackety hack -->.h</a>.
+<p>For details about the C API used to load UIs, see the file pui.h.
</p>
""" .
@@ -140,7 +138,7 @@ instantiate if the host doesn't pass all required features to instantiate().
## Port Protocols ##
####################
-ui:PortProtocol a rdfs:Class;
+pui:PortProtocol a rdfs:Class;
rdfs:subClassOf lv2:Feature;
rdfs:label "Port protocol";
lv2:documentation """
@@ -151,14 +149,14 @@ those extensions MUST specify:
<p><ol>
<li>Which plugin port types the buffer type is valid for</li>
-<li>When the host should call port_event() in LV2_UI_Descriptor</li>
+<li>When the host should call port_event() in LV2_PUI_Descriptor</li>
<li>The format of the data in the buffer passed to port_event()</li>
<li>The format of the data in the buffer passed to write_port()</li>
-<li>What happens when the UI calls write_port() in LV2_UI_Host_Descriptor</li>
+<li>What happens when the UI calls write_port() in LV2_PUI_Host_Descriptor</li>
<li>What data (if any) should be passed in the LV2_Feature data pointer. </li>
</ol></p>
-<p>For an example, see ui:floatControl.
+<p>For an example, see pui:floatControl.
</p>
<p>PortProtocol is a subclass of lv2:Feature, so UIs use lv2:optionalFeature and
@@ -166,10 +164,10 @@ lv2:requiredFeature to specify which PortProtocols they want to use.
</p>
""".
-ui:floatControl a ui:PortProtocol;
+pui:floatControl a pui:PortProtocol;
rdfs:label "Floating point value";
lv2:documentation """
-<p>The rules (see ui:PortProtocol) for this port protocol are:</p>
+<p>The rules (see pui:PortProtocol) for this port protocol are:</p>
<ol>
<li>This PortProtocol is valid for ports with the type lv2:ControlPort.</li>
<li>The host SHOULD call port_event() as soon as possible when the port value
diff --git a/ext/ui.lv2/ui.h b/ext/pui.lv2/pui.h
index 5274cd5..6af445b 100644
--- a/ext/ui.lv2/ui.h
+++ b/ext/pui.lv2/pui.h
@@ -1,6 +1,6 @@
/************************************************************************
*
- * In-process UI extension for LV2
+ * Plugin UI extension for LV2
*
* Copyright (C) 2006-2011 Lars Luthman <mail@larsluthman.net>
*
@@ -28,7 +28,7 @@
***********************************************************************/
/**
- @file ui.h C API for the LV2 UI extension <http://lv2plug.in/ns/ext/ui>.
+ @file pui.h C API for the LV2 UI extension <http://lv2plug.in/ns/ext/pui>.
This file specifies a C API for communication between an LV2 host and an
LV2 UI. The interface is similar to the one used for actual LV2 plugins.
@@ -36,24 +36,24 @@
The entry point is the function lv2ui_descriptor().
*/
-#ifndef LV2_UI_H
-#define LV2_UI_H
+#ifndef LV2_PUI_H
+#define LV2_PUI_H
#include <lv2.h>
/** The URI of this extension (note this is not the same as the prefix). */
#define LV2_UI_URI "http://lv2plug.in/ns/ext/ui"
/** The numerical ID returned by LV2_UI_Host_Descriptor::port_index() for
invalid port symbols. */
#define LV2_UI_INVALID_PORT_INDEX ((uint32_t)-1)
/** The numerical ID returned by LV2_UI_Host_Descriptor::port_protocol_id() for
invalid or unsupported PortProtocols. */
#define LV2_UI_INVALID_PORT_PROTOCOL_ID 0
/** The full URI for the ui:floatControl PortProtocol. */
#define LV2_UI_FLOAT_CONTROL_URI "http://lv2plug.in/ns/ext/ui#floatControl"
#ifdef __cplusplus
extern "C" {
@@ -66,7 +66,7 @@ extern "C" {
host only needs to pass the necessary callbacks and display the widget, if
possible. Plugins may have several UIs, in various toolkits.
*/
-typedef void* LV2_UI_Widget;
+typedef void* LV2_PUI_Widget;
/**
Handle for a particular instance of a UI.
@@ -74,17 +74,17 @@ typedef void* LV2_UI_Widget;
NOT attempt to interpret it. The UI may use it to reference internal
instance data.
*/
-typedef void* LV2_UI_Handle;
+typedef void* LV2_PUI_Handle;
/**
Handle for host functions and data provided to a UI.
An object of this type is passed to the UI's instantiate() function, and the
UI must in turn pass it as the first parameter to the callbacks in
- LV2_UI_Host_Descriptor. The host may use it to reference internal data, such
+ LV2_PUI_Host_Descriptor. The host may use it to reference internal data, such
as the plugin instance that the UI is associated with. The UI MUST NOT
- interpret the value of an LV2_UI_Host_Handle in any way.
+ interpret the value of an LV2_PUI_Host_Handle in any way.
*/
-typedef void* LV2_UI_Host_Handle;
+typedef void* LV2_PUI_Host_Handle;
/**
Host-provided functions that the UI can use to control the plugin instance.
@@ -94,7 +94,7 @@ typedef void* LV2_UI_Host_Handle;
The host MUST provide non-NULL values for all the function pointers.
*/
-typedef struct _LV2_UI_Host_Descriptor {
+typedef struct _LV2_PUI_Host_Descriptor {
/**
Send data to one of the plugin's input ports.
@@ -104,7 +104,7 @@ typedef struct _LV2_UI_Host_Descriptor {
with it depends on the value of the @a port_protocol parameter.
The @a port_protocol parameter MUST be a numeric ID for a
- ui:PortProtocol. Numeric IDs for PortProtocols are retrieved using the
+ pui:PortProtocol. Numeric IDs for PortProtocols are retrieved using the
port_protocol_id() function.
The @a buffer is only valid during the time of this function call, so if
@@ -120,43 +120,43 @@ typedef struct _LV2_UI_Host_Descriptor {
@param port_protocol The numeric ID of the Port Protocol to use,
as returned by port_protocol_id().
*/
- void (*write_port)(LV2_UI_Host_Handle host_handle,
- uint32_t port_index,
- uint32_t buffer_size,
- uint32_t port_protocol,
- void const* buffer);
+ void (*write_port)(LV2_PUI_Host_Handle host_handle,
+ uint32_t port_index,
+ uint32_t buffer_size,
+ uint32_t port_protocol,
+ void const* buffer);
/**
Return the numerical index for a port.
This index is used when writing data to ports using write_port() and whe
receiving data using port_event(). If @a port_symbol is not a valid port
symbol for @a plugin the host it MUST return
- LV2_UI_INVALID_PORT_INDEX. For performance reasons it may be a good idea
+ LV2_PUI_INVALID_PORT_INDEX. For performance reasons it may be a good idea
to cache port indices in the UI at instantiation time.
- @param host_handle The LV2_UI_Host_Handle that was passed to the UI's
+ @param host_handle The LV2_PUI_Host_Handle that was passed to the UI's
instantiate() function.
@param port_symbol The port's symbol, as defined in the RDF data for
the plugin.
*/
- uint32_t (*port_index)(LV2_UI_Host_Handle host_handle,
- char const* port_symbol);
+ uint32_t (*port_index)(LV2_PUI_Host_Handle host_handle,
+ char const* port_symbol);
/**
This function is used by the UI, typically at instantiation, to get
- the numeric IDs that are mapped to certain ui:PortProtocols (see
- ui.ttl for details). If the host does not support the given
- ui:PortProtocol it MUST return LV2_UI_INVALID_PORT_PROTOCOL_ID,
+ the numeric IDs that are mapped to certain pui:PortProtocols (see
+ pui.ttl for details). If the host does not support the given
+ pui:PortProtocol it MUST return LV2_PUI_INVALID_PORT_PROTOCOL_ID,
but the UI SHOULD not rely on this to find out which protocols
are supported, it should check the @a features array passed to
instantiate() for this.
@param host_handle The @a host_handle that was passed to the UI's
instantiate() function.
- @param port_protocol_uri The URI of the ui:PortProtocol.
+ @param port_protocol_uri The URI of the pui:PortProtocol.
*/
- uint32_t (*port_protocol_id)(LV2_UI_Host_Handle host_handle,
- char const* port_protocol_uri);
+ uint32_t (*port_protocol_id)(LV2_PUI_Host_Handle host_handle,
+ char const* port_protocol_uri);
/**
Subscribe to updates for a port.
@@ -172,9 +172,9 @@ typedef struct _LV2_UI_Host_Descriptor {
@param port_protocol The numeric ID of the PortProtocol, as
returned by port_protocol_id().
*/
- void (*add_port_subscription)(LV2_UI_Host_Handle host_handle,
- uint32_t port_index,
- uint32_t port_protocol);
+ void (*add_port_subscription)(LV2_PUI_Host_Handle host_handle,
+ uint32_t port_index,
+ uint32_t port_protocol);
/**
Unsubscribe to updates for a port.
@@ -190,17 +190,17 @@ typedef struct _LV2_UI_Host_Descriptor {
@param port_protocol The numeric ID of the PortProtocol, as
returned by port_protocol_id().
*/
- void (*remove_port_subscription)(LV2_UI_Host_Handle host_handle,
- uint32_t port_index,
- uint32_t port_protocol);
+ void (*remove_port_subscription)(LV2_PUI_Host_Handle host_handle,
+ uint32_t port_index,
+ uint32_t port_protocol);
-} LV2_UI_Host_Descriptor;
+} LV2_PUI_Host_Descriptor;
/**
This struct contains the implementation of an UI. A pointer to an
object of this type is returned by the lv2ui_descriptor() function.
*/
-typedef struct _LV2_UI_Descriptor {
+typedef struct _LV2_PUI_Descriptor {
/**
The URI for this UI (not for the plugin it controls).
@@ -235,32 +235,32 @@ typedef struct _LV2_UI_Descriptor {
the same; @a features will probably not be the same array as the one the
plugin host passes to a plugin.
*/
- LV2_UI_Handle (*instantiate)(struct _LV2_UI_Descriptor const* descriptor,
- char const* plugin_uri,
- char const* bundle_path,
- LV2_UI_Host_Descriptor const* host_descriptor,
- LV2_UI_Host_Handle host_handle,
- LV2_Feature const* const* features);
+ LV2_PUI_Handle (*instantiate)(struct _LV2_PUI_Descriptor const* descriptor,
+ char const* plugin_uri,
+ char const* bundle_path,
+ LV2_PUI_Host_Descriptor const* host_descriptor,
+ LV2_PUI_Host_Handle host_handle,
+ LV2_Feature const* const* features);
/**
Return the widget pointer for the UI object.
This MUST return the same value during the entire lifetime of the UI
object.
*/
- LV2_UI_Widget (*get_widget)(LV2_UI_Handle ui);
+ LV2_PUI_Widget (*get_widget)(LV2_PUI_Handle ui);
/**
Destroy the UI object and the associated widget.
The host must not try to access the widget after calling this function.
*/
- void (*cleanup)(LV2_UI_Handle ui);
+ void (*cleanup)(LV2_PUI_Handle ui);
/**
Notify the UI that something has happened to a subscribed port.
This is called by the host when something happens at a plugin port that
has been subscribed to using
- LV2_UI_Host_Descriptor::add_port_subscription().
+ LV2_PUI_Host_Descriptor::add_port_subscription().
The @a buffer is only valid during the time of this function call, so if
the UI wants to keep it for later use it has to copy the contents to an
@@ -268,29 +268,29 @@ typedef struct _LV2_UI_Descriptor {
@param ui A handle for the UI object.
@param port_index The index of the port that has changed, as returned by
- LV2_UI_Host_Descriptor::port_index().
+ LV2_PUI_Host_Descriptor::port_index().
@param buffer_size The size of the data buffer in bytes.
@param port_protocol The format of the data buffer, as returned by
- LV2_UI_Host_Descriptor::port_protocol_id().
+ LV2_PUI_Host_Descriptor::port_protocol_id().
@param buffer A pointer to the data buffer.
*/
- void (*port_event)(LV2_UI_Handle ui,
- uint32_t port_index,
- uint32_t buffer_size,
- uint32_t port_protocol,
- void const* buffer);
+ void (*port_event)(LV2_PUI_Handle ui,
+ uint32_t port_index,
+ uint32_t buffer_size,
+ uint32_t port_protocol,
+ void const* buffer);
/**
Return a data structure associated with an extension URI.
- This facility can be used by extensions to extend the LV2_UI_Descriptor
+ This facility can be used by extensions to extend the LV2_PUI_Descriptor
API. This function adheres to the same rules as
LV2_Descriptor::extension_data, except it applies to UIs rather than
plugins.
*/
void const* (*extension_data)(char const* uri);
-} LV2_UI_Descriptor;
+} LV2_PUI_Descriptor;
/**
Prototype for UI accessor function.
@@ -298,15 +298,15 @@ typedef struct _LV2_UI_Descriptor {
This function follows the same rules as lv2_desciprotr(), except it applies
to UIs rather than plugins.
*/
-LV2_UI_Descriptor const* lv2ui_descriptor(uint32_t index);
+LV2_PUI_Descriptor const* lv2ui_descriptor(uint32_t index);
/**
Type of the lv2ui_descriptor() function in a UI library.
*/
-typedef LV2_UI_Descriptor const* (*LV2_UI_DescriptorFunction)(uint32_t index);
+typedef LV2_PUI_Descriptor const* (*LV2_PUI_DescriptorFunction)(uint32_t index);
#ifdef __cplusplus
}
#endif
-#endif /* LV2_UI_H */
+#endif /* LV2_PUI_H */
@@ -36,24 +36,24 @@
#include <lv2.h>
/** The URI of this extension (note this is not the same as the prefix). */
-#define LV2_UI_URI "http://lv2plug.in/ns/ext/ui"
+#define LV2_PUI_URI "http://lv2plug.in/ns/ext/pui"
-/** The numerical ID returned by LV2_UI_Host_Descriptor::port_index() for
+/** The numerical ID returned by LV2_PUI_Host_Descriptor::port_index() for
invalid port symbols. */
@@ -36,24 +36,24 @@
invalid port symbols. */
-#define LV2_UI_INVALID_PORT_INDEX ((uint32_t)-1)
+#define LV2_PUI_INVALID_PORT_INDEX ((uint32_t)-1)
-/** The numerical ID returned by LV2_UI_Host_Descriptor::port_protocol_id() for
+/** The numerical ID returned by LV2_PUI_Host_Descriptor::port_protocol_id() for
invalid or unsupported PortProtocols. */
@@ -36,24 +36,24 @@
invalid or unsupported PortProtocols. */
-#define LV2_UI_INVALID_PORT_PROTOCOL_ID 0
+#define LV2_PUI_INVALID_PORT_PROTOCOL_ID 0
-/** The full URI for the ui:floatControl PortProtocol. */
-#define LV2_UI_FLOAT_CONTROL_URI "http://lv2plug.in/ns/ext/ui#floatControl"
+/** The full URI for the pui:floatControl PortProtocol. */
+#define LV2_PUI_FLOAT_CONTROL_URI "http://lv2plug.in/ns/ext/pui#floatControl"
#ifdef __cplusplus
extern "C" {